]> git.cryptolib.org Git - avr-crypto-lib.git/blobdiff - arcfour.c
removement of debug/unfinished code
[avr-crypto-lib.git] / arcfour.c
index 863b7ac8782a83519895379d72b9ba7f746dde32..f8d01a6f12037fca303fd7c105a6a6c7873c9176 100644 (file)
--- a/arcfour.c
+++ b/arcfour.c
@@ -1,8 +1,27 @@
+/* arcfour.c */
+/*
+    This file is part of the Crypto-avr-lib/microcrypt-lib.
+    Copyright (C) 2008  Daniel Otte (daniel.otte@rub.de)
+
+    This program is free software: you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation, either version 3 of the License, or
+    (at your option) any later version.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+*/
 /* 
* File:               arcfour.c
* Author:     Daniel Otte
* Date:       07.06.2006
* License: GPL
  * Description: Implementation of the ARCFOUR (RC4 compatible) stream cipher algorithm.
  * 
  */
@@ -1,8 +1,27 @@
 /* 
- * File:               arcfour.c
- * Author:     Daniel Otte
- * Date:       07.06.2006
- * License: GPL
+ * File:        arcfour.c
+ * Author:      Daniel Otte
+ * email:       daniel.otte@rub.de
+ * Date:        2006-06-07
+ * License:     GPLv3 or later
  * Description: Implementation of the ARCFOUR (RC4 compatible) stream cipher algorithm.
  * 